# collection of shell function and variables  for dpt-* scripts

# to be sourced from dpt-* scripts as
# . "$DPT__SCRIPTS/lib/dpt-lib.sh"

# Copyright 2022, gregor herrmann <gregoa@debian.org>
# Released under the same terms as perl

# documentation in (git) man5/dpt-lib.sh.pod /
# (installed) man 5 dpt-lib.sh

# FUNCTIONS

die() {
	colored "RED" "E: $*" >&2
	exit 1
}

warn() {
	colored "YELLOW" "W: $*" >&2
}

info() {
	colored "GREEN" "I: $*" >&2
}

header() {
	local TITLE="$*"
	local LEN=$(( $(echo "$TITLE" | perl -pe 's/\e\[?.*?[\@-~]//g' | wc --chars) - 1 )) # or sed -e 's/\x1b\[[0-9;]*m//g'
	echo
	colored "CYAN" "$TITLE"
	for i in $(seq $LEN); do
		echo -n "="
	done
	echo
}

anykey () {
	if [ $SHELL = "/bin/bash" ]; then
		bash -c 'read -n 1 -p "Press the anykey ..."'
	elif [ $SHELL = "/bin/zsh" ]; then
		zsh -c 'read -k 1 "?Press the anykey ..."'
	else
		read -p "Press enter ..." DUMMY
	fi
}

is_installed() {
	local PKG=$1
	local VER=${2:-''}

	local D=$(dpkg-query --show $PKG 2>/dev/null)
	local D_PKG=$(echo $D | awk '{print $1}')
	local D_VER=$(echo $D | awk '{print $2}')

	if [ -z "$D_PKG" ]; then
		warn "Package '$PKG' is not installed."
		return 1
	fi
	if [ -n "VER" ] && dpkg --compare-versions $D_VER lt $VER ; then
		warn "Version '$D_VER' of package '$PKG' does not satisfy version requirement '$VER'."
		return 1
	fi
}

is_command() {
	local CMD=$1
	local PKG=${2:-''}
	if ! command -v $CMD >/dev/null; then
		warn "Can't find command '$CMD'."
		if [ -n "$PKG" ]; then
			warn "You might want to install the '$PKG' package."
		fi
		return 1
	fi
}

is_pkg_perl() {
	grep -qF 'pkg-perl-maintainers@lists.alioth.debian.org' debian/control
}

# sanity checks
dh_testdir  || die "This doesn't look like a source package directory."
[ -d .git ] || die "No .git directory found."

# VARIABLES
PKG=$(dpkg-parsechangelog --show-field Source)
VER=$(dpkg-parsechangelog --show-field Version)
UVER=$(echo "$VER" | sed 's,^[0-9]\+:,,; s,-[^-]\+$,,')
DIST=$(dpkg-parsechangelog --show-field Distribution)

## colo(u)rs

C_BLACK=$(tput setaf 0)
C_RED=$(tput setaf 1)
C_GREEN=$(tput setaf 2)
C_YELLOW=$(tput setaf 3)
C_BLUE=$(tput setaf 4)
C_MAGENTA=$(tput setaf 5)
C_CYAN=$(tput setaf 6)
C_WHITE=$(tput setaf 7)
C_RESET=$(tput sgr0)

colored() {
	local COLORNAME=$1
	shift
	local MSG=$*

	# https://unix.stackexchange.com/questions/557361/how-to-dynamically-set-a-variable-name-in-shell-script
	VAR=C_$COLORNAME
	C_SET=$(eval "echo \"\$$VAR\"")

	if [ -n "${NO_COLOR:-}" -o ! -t 1 -o ! -t 2 ]; then
		echo "$MSG"
	else
		echo "${C_SET}${MSG}${C_RESET}"
	fi
}
